#[non_exhaustive]pub enum AssociateDatasetKmsKeyError {
ConflictException(ConflictException),
KmsAccessDeniedException(KmsAccessDeniedException),
KmsKeyDisabledException(KmsKeyDisabledException),
KmsKeyNotFoundException(KmsKeyNotFoundException),
ResourceNotFoundException(ResourceNotFoundException),
Unhandled(Unhandled),
}Expand description
Error type for the AssociateDatasetKmsKeyError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConflictException(ConflictException)
This operation attempted to create a resource that already exists.
KmsAccessDeniedException(KmsAccessDeniedException)
The operation was denied because either the calling principal lacks the required Amazon Web Services Key Management Service (Amazon Web Services KMS) permission on the key, or the key policy does not grant Amazon CloudWatch the permissions it needs to use the key. Verify that the caller has kms:Decrypt permission on the key, and that the key policy grants the CloudWatch service principal the kms:DescribeKey, kms:GenerateDataKey, kms:Encrypt, kms:Decrypt, and kms:ReEncrypt* permissions described in AssociateDatasetKmsKey.
KmsKeyDisabledException(KmsKeyDisabledException)
The specified Amazon Web Services Key Management Service (Amazon Web Services KMS) key is disabled or pending deletion. Re-enable the key (or restore it, if it is pending deletion) and retry the operation.
KmsKeyNotFoundException(KmsKeyNotFoundException)
The specified Amazon Web Services Key Management Service (Amazon Web Services KMS) key could not be found. Verify that the key Amazon Resource Name (ARN) is correct, that the key exists, and that it is in the same Amazon Web Services Region as the resource.
ResourceNotFoundException(ResourceNotFoundException)
The named resource does not exist.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl AssociateDatasetKmsKeyError
impl AssociateDatasetKmsKeyError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the AssociateDatasetKmsKeyError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the AssociateDatasetKmsKeyError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is AssociateDatasetKmsKeyError::ConflictException.
Sourcepub fn is_kms_access_denied_exception(&self) -> bool
pub fn is_kms_access_denied_exception(&self) -> bool
Returns true if the error kind is AssociateDatasetKmsKeyError::KmsAccessDeniedException.
Sourcepub fn is_kms_key_disabled_exception(&self) -> bool
pub fn is_kms_key_disabled_exception(&self) -> bool
Returns true if the error kind is AssociateDatasetKmsKeyError::KmsKeyDisabledException.
Sourcepub fn is_kms_key_not_found_exception(&self) -> bool
pub fn is_kms_key_not_found_exception(&self) -> bool
Returns true if the error kind is AssociateDatasetKmsKeyError::KmsKeyNotFoundException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is AssociateDatasetKmsKeyError::ResourceNotFoundException.