#[non_exhaustive]pub struct DisableInsightRulesInput {
pub rule_names: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_names: Option<Vec<String>>An array of the rule names to disable. If you need to find out the names of your rules, use DescribeInsightRules.
Implementations
Sourceimpl DisableInsightRulesInput
impl DisableInsightRulesInput
Sourcepub fn rule_names(&self) -> &[String]
pub fn rule_names(&self) -> &[String]
An array of the rule names to disable. If you need to find out the names of your rules, use DescribeInsightRules.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .rule_names.is_none().
Sourceimpl DisableInsightRulesInput
impl DisableInsightRulesInput
Sourcepub fn builder() -> DisableInsightRulesInputBuilder
pub fn builder() -> DisableInsightRulesInputBuilder
Creates a new builder-style object to manufacture DisableInsightRulesInput.