#[non_exhaustive]pub struct GetDatasetOutputBuilder { /* private fields */ }Expand description
A builder for GetDatasetOutput.
Implementations
Sourceimpl GetDatasetOutputBuilder
impl GetDatasetOutputBuilder
Sourcepub fn dataset_id(self, input: impl Into<String>) -> Self
pub fn dataset_id(self, input: impl Into<String>) -> Self
Returns the identifier of the dataset.
This field is required.Sourcepub fn set_dataset_id(self, input: Option<String>) -> Self
pub fn set_dataset_id(self, input: Option<String>) -> Self
Returns the identifier of the dataset.
Sourcepub fn get_dataset_id(&self) -> &Option<String>
pub fn get_dataset_id(&self) -> &Option<String>
Returns the identifier of the dataset.
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
Returns the Amazon Resource Name (ARN) of the dataset, in the format arn:aws:cloudwatch:Region:account-id:dataset/dataset-id .
Sourcepub fn set_arn(self, input: Option<String>) -> Self
pub fn set_arn(self, input: Option<String>) -> Self
Returns the Amazon Resource Name (ARN) of the dataset, in the format arn:aws:cloudwatch:Region:account-id:dataset/dataset-id .
Sourcepub fn get_arn(&self) -> &Option<String>
pub fn get_arn(&self) -> &Option<String>
Returns the Amazon Resource Name (ARN) of the dataset, in the format arn:aws:cloudwatch:Region:account-id:dataset/dataset-id .
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
Sourcepub fn build(self) -> GetDatasetOutput
pub fn build(self) -> GetDatasetOutput
Consumes the builder and constructs a GetDatasetOutput.