#[non_exhaustive]pub struct GetDatasetInput {
pub dataset_identifier: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset_identifier: Option<String>Specifies the identifier of the dataset to retrieve. For the default dataset, you can specify either default or the full dataset Amazon Resource Name (ARN) in the format arn:aws:cloudwatch:Region:account-id:dataset/default.
Implementations
Sourceimpl GetDatasetInput
impl GetDatasetInput
Sourcepub fn dataset_identifier(&self) -> Option<&str>
pub fn dataset_identifier(&self) -> Option<&str>
Specifies the identifier of the dataset to retrieve. For the default dataset, you can specify either default or the full dataset Amazon Resource Name (ARN) in the format arn:aws:cloudwatch:Region:account-id:dataset/default.
Sourceimpl GetDatasetInput
impl GetDatasetInput
Sourcepub fn builder() -> GetDatasetInputBuilder
pub fn builder() -> GetDatasetInputBuilder
Creates a new builder-style object to manufacture GetDatasetInput.