#[non_exhaustive]pub struct GetDatasetOutput {
pub dataset_id: Option<String>,
pub arn: Option<String>,
pub kms_key_arn: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset_id: Option<String>Returns the identifier of the dataset.
arn: Option<String>Returns the Amazon Resource Name (ARN) of the dataset, in the format arn:aws:cloudwatch:Region:account-id:dataset/dataset-id .
kms_key_arn: Option<String>Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
Implementations
Sourceimpl GetDatasetOutput
impl GetDatasetOutput
Sourcepub fn dataset_id(&self) -> Option<&str>
pub fn dataset_id(&self) -> Option<&str>
Returns the identifier of the dataset.
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
Returns the Amazon Resource Name (ARN) of the dataset, in the format arn:aws:cloudwatch:Region:account-id:dataset/dataset-id .
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
Returns the Amazon Resource Name (ARN) of the customer managed Amazon Web Services KMS key that is currently associated with the dataset, if any. If the dataset is not associated with a customer managed KMS key, this field is not included in the response and the dataset is encrypted at rest using an Amazon Web Services owned key.
Sourceimpl GetDatasetOutput
impl GetDatasetOutput
Sourcepub fn builder() -> GetDatasetOutputBuilder
pub fn builder() -> GetDatasetOutputBuilder
Creates a new builder-style object to manufacture GetDatasetOutput.