#[non_exhaustive]pub struct DatapointBuilder { /* private fields */ }Expand description
A builder for Datapoint.
Implementations
Sourceimpl DatapointBuilder
impl DatapointBuilder
Sourcepub fn set_timestamp(self, input: Option<DateTime>) -> Self
pub fn set_timestamp(self, input: Option<DateTime>) -> Self
The time stamp used for the data point.
Sourcepub fn get_timestamp(&self) -> &Option<DateTime>
pub fn get_timestamp(&self) -> &Option<DateTime>
The time stamp used for the data point.
Sourcepub fn sample_count(self, input: f64) -> Self
pub fn sample_count(self, input: f64) -> Self
The number of metric values that contributed to the aggregate value of this data point.
Sourcepub fn set_sample_count(self, input: Option<f64>) -> Self
pub fn set_sample_count(self, input: Option<f64>) -> Self
The number of metric values that contributed to the aggregate value of this data point.
Sourcepub fn get_sample_count(&self) -> &Option<f64>
pub fn get_sample_count(&self) -> &Option<f64>
The number of metric values that contributed to the aggregate value of this data point.
Sourcepub fn average(self, input: f64) -> Self
pub fn average(self, input: f64) -> Self
The average of the metric values that correspond to the data point.
Sourcepub fn set_average(self, input: Option<f64>) -> Self
pub fn set_average(self, input: Option<f64>) -> Self
The average of the metric values that correspond to the data point.
Sourcepub fn get_average(&self) -> &Option<f64>
pub fn get_average(&self) -> &Option<f64>
The average of the metric values that correspond to the data point.
Sourcepub fn set_sum(self, input: Option<f64>) -> Self
pub fn set_sum(self, input: Option<f64>) -> Self
The sum of the metric values for the data point.
Sourcepub fn set_minimum(self, input: Option<f64>) -> Self
pub fn set_minimum(self, input: Option<f64>) -> Self
The minimum metric value for the data point.
Sourcepub fn get_minimum(&self) -> &Option<f64>
pub fn get_minimum(&self) -> &Option<f64>
The minimum metric value for the data point.
Sourcepub fn set_maximum(self, input: Option<f64>) -> Self
pub fn set_maximum(self, input: Option<f64>) -> Self
The maximum metric value for the data point.
Sourcepub fn get_maximum(&self) -> &Option<f64>
pub fn get_maximum(&self) -> &Option<f64>
The maximum metric value for the data point.
Sourcepub fn unit(self, input: StandardUnit) -> Self
pub fn unit(self, input: StandardUnit) -> Self
The standard unit for the data point.
Sourcepub fn set_unit(self, input: Option<StandardUnit>) -> Self
pub fn set_unit(self, input: Option<StandardUnit>) -> Self
The standard unit for the data point.
Sourcepub fn get_unit(&self) -> &Option<StandardUnit>
pub fn get_unit(&self) -> &Option<StandardUnit>
The standard unit for the data point.
Sourcepub fn extended_statistics(self, k: impl Into<String>, v: f64) -> Self
pub fn extended_statistics(self, k: impl Into<String>, v: f64) -> Self
Adds a key-value pair to extended_statistics.
To override the contents of this collection use set_extended_statistics.
The percentile statistic for the data point.
Sourcepub fn set_extended_statistics(
self,
input: Option<HashMap<String, f64>>,
) -> Self
pub fn set_extended_statistics( self, input: Option<HashMap<String, f64>>, ) -> Self
The percentile statistic for the data point.