#[non_exhaustive]pub struct ScheduledQueryConfigurationBuilder { /* private fields */ }Expand description
A builder for ScheduledQueryConfiguration.
Implementations
Sourceimpl ScheduledQueryConfigurationBuilder
impl ScheduledQueryConfigurationBuilder
Sourcepub fn query_string(self, input: impl Into<String>) -> Self
pub fn query_string(self, input: impl Into<String>) -> Self
The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.
This field is required.Sourcepub fn set_query_string(self, input: Option<String>) -> Self
pub fn set_query_string(self, input: Option<String>) -> Self
The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.
Sourcepub fn get_query_string(&self) -> &Option<String>
pub fn get_query_string(&self) -> &Option<String>
The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.
Sourcepub fn log_group_identifiers(self, input: impl Into<String>) -> Self
pub fn log_group_identifiers(self, input: impl Into<String>) -> Self
Appends an item to log_group_identifiers.
To override the contents of this collection use set_log_group_identifiers.
The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.
Sourcepub fn set_log_group_identifiers(self, input: Option<Vec<String>>) -> Self
pub fn set_log_group_identifiers(self, input: Option<Vec<String>>) -> Self
The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.
Sourcepub fn get_log_group_identifiers(&self) -> &Option<Vec<String>>
pub fn get_log_group_identifiers(&self) -> &Option<Vec<String>>
The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.
Sourcepub fn query_arn(self, input: impl Into<String>) -> Self
pub fn query_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.
Sourcepub fn set_query_arn(self, input: Option<String>) -> Self
pub fn set_query_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.
Sourcepub fn get_query_arn(&self) -> &Option<String>
pub fn get_query_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.
Sourcepub fn scheduled_query_role_arn(self, input: impl Into<String>) -> Self
pub fn scheduled_query_role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.
This field is required.Sourcepub fn set_scheduled_query_role_arn(self, input: Option<String>) -> Self
pub fn set_scheduled_query_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.
Sourcepub fn get_scheduled_query_role_arn(&self) -> &Option<String>
pub fn get_scheduled_query_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.
Sourcepub fn schedule_configuration(self, input: ScheduleConfiguration) -> Self
pub fn schedule_configuration(self, input: ScheduleConfiguration) -> Self
The schedule and time-range offset configuration for the underlying scheduled query.
This field is required.Sourcepub fn set_schedule_configuration(
self,
input: Option<ScheduleConfiguration>,
) -> Self
pub fn set_schedule_configuration( self, input: Option<ScheduleConfiguration>, ) -> Self
The schedule and time-range offset configuration for the underlying scheduled query.
Sourcepub fn get_schedule_configuration(&self) -> &Option<ScheduleConfiguration>
pub fn get_schedule_configuration(&self) -> &Option<ScheduleConfiguration>
The schedule and time-range offset configuration for the underlying scheduled query.
Sourcepub fn aggregation_expression(self, input: impl Into<String>) -> Self
pub fn aggregation_expression(self, input: impl Into<String>) -> Self
The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.
Sourcepub fn set_aggregation_expression(self, input: Option<String>) -> Self
pub fn set_aggregation_expression(self, input: Option<String>) -> Self
The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.
Sourcepub fn get_aggregation_expression(&self) -> &Option<String>
pub fn get_aggregation_expression(&self) -> &Option<String>
The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.
Appends an item to tags.
To override the contents of this collection use set_tags.
A list of key-value pairs to associate with the underlying scheduled query resource.
A list of key-value pairs to associate with the underlying scheduled query resource.
A list of key-value pairs to associate with the underlying scheduled query resource.
Sourcepub fn build(self) -> ScheduledQueryConfiguration
pub fn build(self) -> ScheduledQueryConfiguration
Consumes the builder and constructs a ScheduledQueryConfiguration.