#[non_exhaustive]pub struct WallClockWindowBuilder { /* private fields */ }Expand description
A builder for WallClockWindow.
Implementations
Sourceimpl WallClockWindowBuilder
impl WallClockWindowBuilder
Sourcepub fn timezone(self, input: impl Into<String>) -> Self
pub fn timezone(self, input: impl Into<String>) -> Self
The time zone to use when the alarm aligns the evaluation window to clock boundaries. You can specify an IANA time zone name (for example, America/New_York), a fixed UTC offset (for example, +05:30), or an offset-prefixed identifier (for example, UTC+05:30). The offset must be aligned to a multiple of 5 minutes. If you don't specify a time zone, CloudWatch uses UTC.
The time zone affects window alignment for all periods, including periods of one hour or shorter.
Sourcepub fn set_timezone(self, input: Option<String>) -> Self
pub fn set_timezone(self, input: Option<String>) -> Self
The time zone to use when the alarm aligns the evaluation window to clock boundaries. You can specify an IANA time zone name (for example, America/New_York), a fixed UTC offset (for example, +05:30), or an offset-prefixed identifier (for example, UTC+05:30). The offset must be aligned to a multiple of 5 minutes. If you don't specify a time zone, CloudWatch uses UTC.
The time zone affects window alignment for all periods, including periods of one hour or shorter.
Sourcepub fn get_timezone(&self) -> &Option<String>
pub fn get_timezone(&self) -> &Option<String>
The time zone to use when the alarm aligns the evaluation window to clock boundaries. You can specify an IANA time zone name (for example, America/New_York), a fixed UTC offset (for example, +05:30), or an offset-prefixed identifier (for example, UTC+05:30). The offset must be aligned to a multiple of 5 minutes. If you don't specify a time zone, CloudWatch uses UTC.
The time zone affects window alignment for all periods, including periods of one hour or shorter.
Sourcepub fn build(self) -> WallClockWindow
pub fn build(self) -> WallClockWindow
Consumes the builder and constructs a WallClockWindow.