#[non_exhaustive]pub enum EvaluationWindow {
SlidingWindow(SlidingWindow),
WallClockWindow(WallClockWindow),
#[non_exhaustive] Unknown,
}Expand description
The evaluation window that an alarm uses to select the range of metric data that it evaluates each time it runs. This is a union type. Set exactly one of its members, SlidingWindow or WallClockWindow. If you don't set EvaluationWindow, the alarm uses a SlidingWindow by default.
For more information, see Alarm evaluation windows in the CloudWatch User Guide.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SlidingWindow(SlidingWindow)
A sliding window, which advances each time the alarm is evaluated, forming a rolling time window. This is the default evaluation window.
WallClockWindow(WallClockWindow)
A wall clock window, which aligns the evaluated range to fixed clock boundaries that match the alarm's period, such as the top of the hour, midnight, or the start of the calendar week.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl EvaluationWindow
impl EvaluationWindow
Sourcepub fn as_sliding_window(&self) -> Result<&SlidingWindow, &Self>
pub fn as_sliding_window(&self) -> Result<&SlidingWindow, &Self>
Tries to convert the enum instance into SlidingWindow, extracting the inner SlidingWindow.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_sliding_window(&self) -> bool
pub fn is_sliding_window(&self) -> bool
Returns true if this is a SlidingWindow.
Sourcepub fn as_wall_clock_window(&self) -> Result<&WallClockWindow, &Self>
pub fn as_wall_clock_window(&self) -> Result<&WallClockWindow, &Self>
Tries to convert the enum instance into WallClockWindow, extracting the inner WallClockWindow.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_wall_clock_window(&self) -> bool
pub fn is_wall_clock_window(&self) -> bool
Returns true if this is a WallClockWindow.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.