AnomalyDetector

Struct AnomalyDetector 

#[non_exhaustive]
pub struct AnomalyDetector { pub anomaly_detector_id: Option<String>, pub namespace: Option<String>, pub metric_name: Option<String>, pub dimensions: Option<Vec<Dimension>>, pub stat: Option<String>, pub configuration: Option<AnomalyDetectorConfiguration>, pub state_value: Option<AnomalyDetectorStateValue>, pub metric_characteristics: Option<MetricCharacteristics>, pub single_metric_anomaly_detector: Option<SingleMetricAnomalyDetector>, pub metric_math_anomaly_detector: Option<MetricMathAnomalyDetector>, }
An anomaly detection model associated with a particular CloudWatch metric, statistic, or metric math expression. You can use the model to display a band of expected, normal values when the metric is graphed.

If you have enabled unified cross-account observability, and this account is a monitoring account, the metric can be in the same account or a source account.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
anomaly_detector_id: Option<String>

The unique identifier of the anomaly detector.

The identifier does not restrict access to a specific anomaly detector in an IAM policy. Permissions for anomaly detector operations apply to all anomaly detectors in the account.

namespace: Option<String>
👎Deprecated:

Use SingleMetricAnomalyDetector.Namespace property.

The namespace of the metric associated with the anomaly detection model.

metric_name: Option<String>
👎Deprecated:

Use SingleMetricAnomalyDetector.MetricName property.

The name of the metric associated with the anomaly detection model.

dimensions: Option<Vec<Dimension>>
👎Deprecated:

Use SingleMetricAnomalyDetector.Dimensions property.

The metric dimensions associated with the anomaly detection model.

stat: Option<String>
👎Deprecated:

Use SingleMetricAnomalyDetector.Stat property.

The statistic associated with the anomaly detection model.

configuration: Option<AnomalyDetectorConfiguration>

The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude from use for training the model, and the time zone to use for the metric.

state_value: Option<AnomalyDetectorStateValue>

The current status of the anomaly detector's training.

metric_characteristics: Option<MetricCharacteristics>

This object includes parameters that you can use to provide information about your metric to CloudWatch to help it build more accurate anomaly detection models. Currently, it includes the PeriodicSpikes parameter.

single_metric_anomaly_detector: Option<SingleMetricAnomalyDetector>

The CloudWatch metric and statistic for this anomaly detector.

metric_math_anomaly_detector: Option<MetricMathAnomalyDetector>

The CloudWatch metric math expression for this anomaly detector.

Implementations

Source

impl AnomalyDetector

pub fn anomaly_detector_id(&self) -> Option<&str>

The unique identifier of the anomaly detector.

The identifier does not restrict access to a specific anomaly detector in an IAM policy. Permissions for anomaly detector operations apply to all anomaly detectors in the account.

pub fn namespace(&self) -> Option<&str>

👎Deprecated:

Use SingleMetricAnomalyDetector.Namespace property.

The namespace of the metric associated with the anomaly detection model.

pub fn metric_name(&self) -> Option<&str>

👎Deprecated:

Use SingleMetricAnomalyDetector.MetricName property.

The name of the metric associated with the anomaly detection model.

pub fn dimensions(&self) -> &[Dimension]

👎Deprecated:

Use SingleMetricAnomalyDetector.Dimensions property.

The metric dimensions associated with the anomaly detection model.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .dimensions.is_none().

pub fn stat(&self) -> Option<&str>

👎Deprecated:

Use SingleMetricAnomalyDetector.Stat property.

The statistic associated with the anomaly detection model.

pub fn configuration(&self) -> Option<&AnomalyDetectorConfiguration>

The configuration specifies details about how the anomaly detection model is to be trained, including time ranges to exclude from use for training the model, and the time zone to use for the metric.

pub fn state_value(&self) -> Option<&AnomalyDetectorStateValue>

The current status of the anomaly detector's training.

pub fn metric_characteristics(&self) -> Option<&MetricCharacteristics>

This object includes parameters that you can use to provide information about your metric to CloudWatch to help it build more accurate anomaly detection models. Currently, it includes the PeriodicSpikes parameter.

pub fn single_metric_anomaly_detector( &self, ) -> Option<&SingleMetricAnomalyDetector>

The CloudWatch metric and statistic for this anomaly detector.

pub fn metric_math_anomaly_detector(&self) -> Option<&MetricMathAnomalyDetector>

The CloudWatch metric math expression for this anomaly detector.

Source

impl AnomalyDetector

pub fn builder() -> AnomalyDetectorBuilder

Creates a new builder-style object to manufacture AnomalyDetector.