#[non_exhaustive]pub struct Datapoint {
pub timestamp: Option<DateTime>,
pub sample_count: Option<f64>,
pub average: Option<f64>,
pub sum: Option<f64>,
pub minimum: Option<f64>,
pub maximum: Option<f64>,
pub unit: Option<StandardUnit>,
pub extended_statistics: Option<HashMap<String, f64>>,
}Expand description
Encapsulates the statistical data that CloudWatch computes from metric data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp: Option<DateTime>The time stamp used for the data point.
sample_count: Option<f64>The number of metric values that contributed to the aggregate value of this data point.
average: Option<f64>The average of the metric values that correspond to the data point.
sum: Option<f64>The sum of the metric values for the data point.
minimum: Option<f64>The minimum metric value for the data point.
maximum: Option<f64>The maximum metric value for the data point.
unit: Option<StandardUnit>The standard unit for the data point.
extended_statistics: Option<HashMap<String, f64>>The percentile statistic for the data point.
Implementations
Sourceimpl Datapoint
impl Datapoint
Sourcepub fn sample_count(&self) -> Option<f64>
pub fn sample_count(&self) -> Option<f64>
The number of metric values that contributed to the aggregate value of this data point.
Sourcepub fn average(&self) -> Option<f64>
pub fn average(&self) -> Option<f64>
The average of the metric values that correspond to the data point.
Sourcepub fn unit(&self) -> Option<&StandardUnit>
pub fn unit(&self) -> Option<&StandardUnit>
The standard unit for the data point.