#[non_exhaustive]pub struct Entity {
pub key_attributes: Option<HashMap<String, String>>,
pub attributes: Option<HashMap<String, String>>,
}Expand description
An entity associated with metrics, to allow for finding related telemetry. An entity is typically a resource or service within your system. For example, metrics from an Amazon EC2 instance could be associated with that instance as the entity. Similarly, metrics from a service that you own could be associated with that service as the entity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_attributes: Option<HashMap<String, String>>The attributes of the entity which identify the specific entity, as a list of key-value pairs. Entities with the same KeyAttributes are considered to be the same entity. For an entity to be valid, the KeyAttributes must exist and be formatted correctly.
There are five allowed attributes (key names): Type, ResourceType, Identifier, Name, and Environment.
For details about how to use the key attributes to specify an entity, see How to add related information to telemetry in the CloudWatch User Guide.
attributes: Option<HashMap<String, String>>Additional attributes of the entity that are not used to specify the identity of the entity. A list of key-value pairs.
For details about how to use the attributes, see How to add related information to telemetry in the CloudWatch User Guide.
Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn key_attributes(&self) -> Option<&HashMap<String, String>>
pub fn key_attributes(&self) -> Option<&HashMap<String, String>>
The attributes of the entity which identify the specific entity, as a list of key-value pairs. Entities with the same KeyAttributes are considered to be the same entity. For an entity to be valid, the KeyAttributes must exist and be formatted correctly.
There are five allowed attributes (key names): Type, ResourceType, Identifier, Name, and Environment.
For details about how to use the key attributes to specify an entity, see How to add related information to telemetry in the CloudWatch User Guide.
Sourcepub fn attributes(&self) -> Option<&HashMap<String, String>>
pub fn attributes(&self) -> Option<&HashMap<String, String>>
Additional attributes of the entity that are not used to specify the identity of the entity. A list of key-value pairs.
For details about how to use the attributes, see How to add related information to telemetry in the CloudWatch User Guide.