#[non_exhaustive]pub struct InsightRuleContributor {
pub keys: Option<Vec<String>>,
pub approximate_aggregate_value: Option<f64>,
pub datapoints: Option<Vec<InsightRuleContributorDatapoint>>,
}Expand description
One of the unique contributors found by a Contributor Insights rule. If the rule contains multiple keys, then a unique contributor is a unique combination of values from all the keys in the rule.
If the rule contains a single key, then each unique contributor is each unique value for this key.
For more information, see GetInsightRuleReport.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.keys: Option<Vec<String>>One of the log entry field keywords that is used to define contributors for this rule.
approximate_aggregate_value: Option<f64>An approximation of the aggregate value that comes from this contributor.
datapoints: Option<Vec<InsightRuleContributorDatapoint>>An array of the data points where this contributor is present. Only the data points when this contributor appeared are included in the array.
Implementations
Sourceimpl InsightRuleContributor
impl InsightRuleContributor
Sourcepub fn keys(&self) -> &[String]
pub fn keys(&self) -> &[String]
One of the log entry field keywords that is used to define contributors for this rule.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .keys.is_none().
Sourcepub fn approximate_aggregate_value(&self) -> Option<f64>
pub fn approximate_aggregate_value(&self) -> Option<f64>
An approximation of the aggregate value that comes from this contributor.
Sourcepub fn datapoints(&self) -> &[InsightRuleContributorDatapoint]
pub fn datapoints(&self) -> &[InsightRuleContributorDatapoint]
An array of the data points where this contributor is present. Only the data points when this contributor appeared are included in the array.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .datapoints.is_none().
Sourceimpl InsightRuleContributor
impl InsightRuleContributor
Sourcepub fn builder() -> InsightRuleContributorBuilder
pub fn builder() -> InsightRuleContributorBuilder
Creates a new builder-style object to manufacture InsightRuleContributor.