#[non_exhaustive]pub struct ManagedRule {
pub template_name: Option<String>,
pub resource_arn: Option<String>,
pub tags: Option<Vec<Tag>>,
}Expand description
Contains the information that's required to enable a managed Contributor Insights rule for an Amazon Web Services resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.template_name: Option<String>The template name for the managed Contributor Insights rule, as returned by ListManagedInsightRules.
resource_arn: Option<String>The ARN of an Amazon Web Services resource that has managed Contributor Insights rules.
A list of key-value pairs that you can associate with a managed Contributor Insights rule. You can associate as many as 50 tags with a rule. Tags can help you organize and categorize your resources. You also can use them to scope user permissions by granting a user permission to access or change only the resources that have certain tag values. To associate tags with a rule, you must have the cloudwatch:TagResource permission in addition to the cloudwatch:PutInsightRule permission. If you are using this operation to update an existing Contributor Insights rule, any tags that you specify in this parameter are ignored. To change the tags of an existing rule, use TagResource.
Implementations
Sourceimpl ManagedRule
impl ManagedRule
Sourcepub fn template_name(&self) -> Option<&str>
pub fn template_name(&self) -> Option<&str>
The template name for the managed Contributor Insights rule, as returned by ListManagedInsightRules.
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
The ARN of an Amazon Web Services resource that has managed Contributor Insights rules.
A list of key-value pairs that you can associate with a managed Contributor Insights rule. You can associate as many as 50 tags with a rule. Tags can help you organize and categorize your resources. You also can use them to scope user permissions by granting a user permission to access or change only the resources that have certain tag values. To associate tags with a rule, you must have the cloudwatch:TagResource permission in addition to the cloudwatch:PutInsightRule permission. If you are using this operation to update an existing Contributor Insights rule, any tags that you specify in this parameter are ignored. To change the tags of an existing rule, use TagResource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl ManagedRule
impl ManagedRule
Sourcepub fn builder() -> ManagedRuleBuilder
pub fn builder() -> ManagedRuleBuilder
Creates a new builder-style object to manufacture ManagedRule.