#[non_exhaustive]pub struct ManagedRuleDescription {
pub template_name: Option<String>,
pub resource_arn: Option<String>,
pub rule_state: Option<ManagedRuleState>,
}Expand description
Contains information about managed Contributor Insights rules, as returned by ListManagedInsightRules.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.template_name: Option<String>The template name for the managed rule. Used to enable managed rules using PutManagedInsightRules.
resource_arn: Option<String>If a managed rule is enabled, this is the ARN for the related Amazon Web Services resource.
rule_state: Option<ManagedRuleState>Describes the state of a managed rule. If present, it contains information about the Contributor Insights rule that contains information about the related Amazon Web Services resource.
Implementations
Sourceimpl ManagedRuleDescription
impl ManagedRuleDescription
Sourcepub fn template_name(&self) -> Option<&str>
pub fn template_name(&self) -> Option<&str>
The template name for the managed rule. Used to enable managed rules using PutManagedInsightRules.
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
If a managed rule is enabled, this is the ARN for the related Amazon Web Services resource.
Sourcepub fn rule_state(&self) -> Option<&ManagedRuleState>
pub fn rule_state(&self) -> Option<&ManagedRuleState>
Describes the state of a managed rule. If present, it contains information about the Contributor Insights rule that contains information about the related Amazon Web Services resource.
Sourceimpl ManagedRuleDescription
impl ManagedRuleDescription
Sourcepub fn builder() -> ManagedRuleDescriptionBuilder
pub fn builder() -> ManagedRuleDescriptionBuilder
Creates a new builder-style object to manufacture ManagedRuleDescription.