#[non_exhaustive]pub struct MetricCharacteristics {
pub periodic_spikes: Option<bool>,
}Expand description
This object includes parameters that you can use to provide information to CloudWatch to help it build more accurate anomaly detection models.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.periodic_spikes: Option<bool>Set this parameter to true if values for this metric consistently include spikes that should not be considered to be anomalies. With this set to true, CloudWatch will expect to see spikes that occurred consistently during the model training period, and won't flag future similar spikes as anomalies.
Implementations
Sourceimpl MetricCharacteristics
impl MetricCharacteristics
Sourcepub fn periodic_spikes(&self) -> Option<bool>
pub fn periodic_spikes(&self) -> Option<bool>
Set this parameter to true if values for this metric consistently include spikes that should not be considered to be anomalies. With this set to true, CloudWatch will expect to see spikes that occurred consistently during the model training period, and won't flag future similar spikes as anomalies.
Sourceimpl MetricCharacteristics
impl MetricCharacteristics
Sourcepub fn builder() -> MetricCharacteristicsBuilder
pub fn builder() -> MetricCharacteristicsBuilder
Creates a new builder-style object to manufacture MetricCharacteristics.