#[non_exhaustive]pub struct MetricMathAnomalyDetector {
pub metric_data_queries: Option<Vec<MetricDataQuery>>,
}Expand description
Indicates the CloudWatch math expression that provides the time series the anomaly detector uses as input. The designated math expression must return a single time series.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.metric_data_queries: Option<Vec<MetricDataQuery>>An array of metric data query structures that enables you to create an anomaly detector based on the result of a metric math expression. Each item in MetricDataQueries gets a metric or performs a math expression. One item in MetricDataQueries is the expression that provides the time series that the anomaly detector uses as input. Designate the expression by setting ReturnData to true for this object in the array. For all other expressions and metrics, set ReturnData to false. The designated expression must return a single time series.
Implementations
Sourceimpl MetricMathAnomalyDetector
impl MetricMathAnomalyDetector
Sourcepub fn metric_data_queries(&self) -> &[MetricDataQuery]
pub fn metric_data_queries(&self) -> &[MetricDataQuery]
An array of metric data query structures that enables you to create an anomaly detector based on the result of a metric math expression. Each item in MetricDataQueries gets a metric or performs a math expression. One item in MetricDataQueries is the expression that provides the time series that the anomaly detector uses as input. Designate the expression by setting ReturnData to true for this object in the array. For all other expressions and metrics, set ReturnData to false. The designated expression must return a single time series.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .metric_data_queries.is_none().
Sourceimpl MetricMathAnomalyDetector
impl MetricMathAnomalyDetector
Sourcepub fn builder() -> MetricMathAnomalyDetectorBuilder
pub fn builder() -> MetricMathAnomalyDetectorBuilder
Creates a new builder-style object to manufacture MetricMathAnomalyDetector.