#[non_exhaustive]pub struct MetricStreamEntry {
pub arn: Option<String>,
pub creation_date: Option<DateTime>,
pub last_update_date: Option<DateTime>,
pub name: Option<String>,
pub firehose_arn: Option<String>,
pub state: Option<String>,
pub output_format: Option<MetricStreamOutputFormat>,
}Expand description
This structure contains the configuration information about one metric stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Option<String>The ARN of the metric stream.
creation_date: Option<DateTime>The date that the metric stream was originally created.
last_update_date: Option<DateTime>The date that the configuration of this metric stream was most recently updated.
name: Option<String>The name of the metric stream.
firehose_arn: Option<String>The ARN of the Kinesis Firehose devlivery stream that is used for this metric stream.
state: Option<String>The current state of this stream. Valid values are running and stopped.
output_format: Option<MetricStreamOutputFormat>The output format of this metric stream. Valid values are json, opentelemetry1.0, and opentelemetry0.7.
Implementations
Sourceimpl MetricStreamEntry
impl MetricStreamEntry
Sourcepub fn creation_date(&self) -> Option<&DateTime>
pub fn creation_date(&self) -> Option<&DateTime>
The date that the metric stream was originally created.
Sourcepub fn last_update_date(&self) -> Option<&DateTime>
pub fn last_update_date(&self) -> Option<&DateTime>
The date that the configuration of this metric stream was most recently updated.
Sourcepub fn firehose_arn(&self) -> Option<&str>
pub fn firehose_arn(&self) -> Option<&str>
The ARN of the Kinesis Firehose devlivery stream that is used for this metric stream.
Sourcepub fn state(&self) -> Option<&str>
pub fn state(&self) -> Option<&str>
The current state of this stream. Valid values are running and stopped.
Sourcepub fn output_format(&self) -> Option<&MetricStreamOutputFormat>
pub fn output_format(&self) -> Option<&MetricStreamOutputFormat>
The output format of this metric stream. Valid values are json, opentelemetry1.0, and opentelemetry0.7.
Sourceimpl MetricStreamEntry
impl MetricStreamEntry
Sourcepub fn builder() -> MetricStreamEntryBuilder
pub fn builder() -> MetricStreamEntryBuilder
Creates a new builder-style object to manufacture MetricStreamEntry.