#[non_exhaustive]pub struct StatisticSet {
pub sample_count: Option<f64>,
pub sum: Option<f64>,
pub minimum: Option<f64>,
pub maximum: Option<f64>,
}Expand description
Represents a set of statistics that describes a specific metric.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sample_count: Option<f64>The number of samples used for the statistic set.
sum: Option<f64>The sum of values for the sample set.
minimum: Option<f64>The minimum value of the sample set.
maximum: Option<f64>The maximum value of the sample set.
Implementations
Sourceimpl StatisticSet
impl StatisticSet
Sourcepub fn sample_count(&self) -> Option<f64>
pub fn sample_count(&self) -> Option<f64>
The number of samples used for the statistic set.
Sourceimpl StatisticSet
impl StatisticSet
Sourcepub fn builder() -> StatisticSetBuilder
pub fn builder() -> StatisticSetBuilder
Creates a new builder-style object to manufacture StatisticSet.