#[non_exhaustive]pub struct InsightRuleBuilder { /* private fields */ }Expand description
A builder for InsightRule.
Implementations
Sourceimpl InsightRuleBuilder
impl InsightRuleBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the rule.
This field is required.Sourcepub fn state(self, input: impl Into<String>) -> Self
pub fn state(self, input: impl Into<String>) -> Self
Indicates whether the rule is enabled or disabled.
This field is required.Sourcepub fn set_state(self, input: Option<String>) -> Self
pub fn set_state(self, input: Option<String>) -> Self
Indicates whether the rule is enabled or disabled.
Sourcepub fn schema(self, input: impl Into<String>) -> Self
pub fn schema(self, input: impl Into<String>) -> Self
For rules that you create, this is always {"Name": "CloudWatchLogRule", "Version": 1}. For managed rules, this is {"Name": "ServiceLogRule", "Version": 1}
Sourcepub fn set_schema(self, input: Option<String>) -> Self
pub fn set_schema(self, input: Option<String>) -> Self
For rules that you create, this is always {"Name": "CloudWatchLogRule", "Version": 1}. For managed rules, this is {"Name": "ServiceLogRule", "Version": 1}
Sourcepub fn get_schema(&self) -> &Option<String>
pub fn get_schema(&self) -> &Option<String>
For rules that you create, this is always {"Name": "CloudWatchLogRule", "Version": 1}. For managed rules, this is {"Name": "ServiceLogRule", "Version": 1}
Sourcepub fn definition(self, input: impl Into<String>) -> Self
pub fn definition(self, input: impl Into<String>) -> Self
The definition of the rule, as a JSON object. The definition contains the keywords used to define contributors, the value to aggregate on if this rule returns a sum instead of a count, and the filters. For details on the valid syntax, see Contributor Insights Rule Syntax.
This field is required.Sourcepub fn set_definition(self, input: Option<String>) -> Self
pub fn set_definition(self, input: Option<String>) -> Self
The definition of the rule, as a JSON object. The definition contains the keywords used to define contributors, the value to aggregate on if this rule returns a sum instead of a count, and the filters. For details on the valid syntax, see Contributor Insights Rule Syntax.
Sourcepub fn get_definition(&self) -> &Option<String>
pub fn get_definition(&self) -> &Option<String>
The definition of the rule, as a JSON object. The definition contains the keywords used to define contributors, the value to aggregate on if this rule returns a sum instead of a count, and the filters. For details on the valid syntax, see Contributor Insights Rule Syntax.
Sourcepub fn managed_rule(self, input: bool) -> Self
pub fn managed_rule(self, input: bool) -> Self
An optional built-in rule that Amazon Web Services manages.
Sourcepub fn set_managed_rule(self, input: Option<bool>) -> Self
pub fn set_managed_rule(self, input: Option<bool>) -> Self
An optional built-in rule that Amazon Web Services manages.
Sourcepub fn get_managed_rule(&self) -> &Option<bool>
pub fn get_managed_rule(&self) -> &Option<bool>
An optional built-in rule that Amazon Web Services manages.
Sourcepub fn apply_on_transformed_logs(self, input: bool) -> Self
pub fn apply_on_transformed_logs(self, input: bool) -> Self
Displays whether the rule is evaluated on the transformed versions of logs, for log groups that have Log transformation enabled. If this is false, log events are evaluated before they are transformed.
Sourcepub fn set_apply_on_transformed_logs(self, input: Option<bool>) -> Self
pub fn set_apply_on_transformed_logs(self, input: Option<bool>) -> Self
Displays whether the rule is evaluated on the transformed versions of logs, for log groups that have Log transformation enabled. If this is false, log events are evaluated before they are transformed.
Sourcepub fn get_apply_on_transformed_logs(&self) -> &Option<bool>
pub fn get_apply_on_transformed_logs(&self) -> &Option<bool>
Displays whether the rule is evaluated on the transformed versions of logs, for log groups that have Log transformation enabled. If this is false, log events are evaluated before they are transformed.
Sourcepub fn build(self) -> InsightRule
pub fn build(self) -> InsightRule
Consumes the builder and constructs a InsightRule.