InsightRuleMetricDatapoint

Struct InsightRuleMetricDatapoint 

#[non_exhaustive]
pub struct InsightRuleMetricDatapoint { pub timestamp: Option<DateTime>, pub unique_contributors: Option<f64>, pub max_contributor_value: Option<f64>, pub sample_count: Option<f64>, pub average: Option<f64>, pub sum: Option<f64>, pub minimum: Option<f64>, pub maximum: Option<f64>, }
One data point from the metric time series returned in a Contributor Insights rule report.

For more information, see GetInsightRuleReport.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
timestamp: Option<DateTime>

The timestamp of the data point.

unique_contributors: Option<f64>

The number of unique contributors who published data during this timestamp.

This statistic is returned only if you included it in the Metrics array in your request.

max_contributor_value: Option<f64>

The maximum value provided by one contributor during this timestamp. Each timestamp is evaluated separately, so the identity of the max contributor could be different for each timestamp.

This statistic is returned only if you included it in the Metrics array in your request.

sample_count: Option<f64>

The number of occurrences that matched the rule during this data point.

This statistic is returned only if you included it in the Metrics array in your request.

average: Option<f64>

The average value from all contributors during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

sum: Option<f64>

The sum of the values from all contributors during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

minimum: Option<f64>

The minimum value from a single contributor during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

maximum: Option<f64>

The maximum value from a single occurence from a single contributor during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

Implementations

Source

impl InsightRuleMetricDatapoint

pub fn timestamp(&self) -> Option<&DateTime>

The timestamp of the data point.

pub fn unique_contributors(&self) -> Option<f64>

The number of unique contributors who published data during this timestamp.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn max_contributor_value(&self) -> Option<f64>

The maximum value provided by one contributor during this timestamp. Each timestamp is evaluated separately, so the identity of the max contributor could be different for each timestamp.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn sample_count(&self) -> Option<f64>

The number of occurrences that matched the rule during this data point.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn average(&self) -> Option<f64>

The average value from all contributors during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn sum(&self) -> Option<f64>

The sum of the values from all contributors during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn minimum(&self) -> Option<f64>

The minimum value from a single contributor during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

pub fn maximum(&self) -> Option<f64>

The maximum value from a single occurence from a single contributor during the time period represented by that data point.

This statistic is returned only if you included it in the Metrics array in your request.

Source

impl InsightRuleMetricDatapoint

pub fn builder() -> InsightRuleMetricDatapointBuilder

Creates a new builder-style object to manufacture InsightRuleMetricDatapoint.