ScheduledQueryConfiguration

Struct ScheduledQueryConfiguration 

#[non_exhaustive]
pub struct ScheduledQueryConfiguration { pub query_string: Option<String>, pub log_group_identifiers: Option<Vec<String>>, pub query_arn: Option<String>, pub scheduled_query_role_arn: Option<String>, pub schedule_configuration: Option<ScheduleConfiguration>, pub aggregation_expression: Option<String>, pub tags: Option<Vec<Tag>>, }
The configuration of the CloudWatch Logs scheduled query that backs a log alarm.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query_string: Option<String>

The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.

log_group_identifiers: Option<Vec<String>>

The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.

query_arn: Option<String>

The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.

scheduled_query_role_arn: Option<String>

The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.

schedule_configuration: Option<ScheduleConfiguration>

The schedule and time-range offset configuration for the underlying scheduled query.

aggregation_expression: Option<String>

The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.

tags: Option<Vec<Tag>>

A list of key-value pairs to associate with the underlying scheduled query resource.

Implementations

Source

impl ScheduledQueryConfiguration

pub fn query_string(&self) -> Option<&str>

The CloudWatch Logs query to execute on each scheduled run. Length constraints: maximum of 10,000 characters.

pub fn log_group_identifiers(&self) -> &[String]

The log groups to query. Each entry can be a log group name or ARN. Use the ARN form when querying log groups in a different account (for example, when running cross-account queries from a monitoring account). The list must contain between 1 and 50 entries.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .log_group_identifiers.is_none().

pub fn query_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the CloudWatch Logs scheduled query that the alarm uses. This field is populated in DescribeAlarms responses.

pub fn scheduled_query_role_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the IAM role that CloudWatch assumes when executing the scheduled query against the configured log groups.

pub fn schedule_configuration(&self) -> Option<&ScheduleConfiguration>

The schedule and time-range offset configuration for the underlying scheduled query.

pub fn aggregation_expression(&self) -> Option<&str>

The expression that defines how to aggregate query results into one or more scalar values for alarm evaluation. For example, count(*) or avg(latency) by host | sort desc. Length constraints: minimum 1 character, maximum 2048 characters.

pub fn tags(&self) -> &[Tag]

A list of key-value pairs to associate with the underlying scheduled query resource.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().

Source

impl ScheduledQueryConfiguration

pub fn builder() -> ScheduledQueryConfigurationBuilder

Creates a new builder-style object to manufacture ScheduledQueryConfiguration.